@@ -15,10 +15,10 @@ import { boolean, string } from '@oclif/parser/lib/flags'
 import { cli } from 'cli-ux'
 import * as Listr from 'listr'
 import * as semver from 'semver'
-import { ChectlContext, OLM } from '../../api/context'
+import { ChectlContext, OIDCContextKeys, OLM } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
 import { batch, cheDeployment, cheDeployVersion, cheNamespace, cheOperatorCRPatchYaml, cheOperatorCRYaml, CHE_OPERATOR_CR_PATCH_YAML_KEY, CHE_OPERATOR_CR_YAML_KEY, CHE_TELEMETRY, DEPLOY_VERSION_KEY, k8sPodDownloadImageTimeout, K8SPODDOWNLOADIMAGETIMEOUT_KEY, k8sPodErrorRecheckTimeout, K8SPODERRORRECHECKTIMEOUT_KEY, k8sPodReadyTimeout, K8SPODREADYTIMEOUT_KEY, k8sPodWaitTimeout, K8SPODWAITTIMEOUT_KEY, listrRenderer, logsDirectory, LOG_DIRECTORY_KEY, skipKubeHealthzCheck as skipK8sHealthCheck } from '../../common-flags'
-import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_NAMESPACE, DEFAULT_OLM_SUGGESTED_NAMESPACE, DOCS_LINK_INSTALL_RUNNING_CHE_LOCALLY, MIN_CHE_OPERATOR_INSTALLER_VERSION, MIN_OLM_INSTALLER_VERSION, OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME } from '../../constants'
+import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_NAMESPACE, DEFAULT_OLM_SUGGESTED_NAMESPACE, DOCS_LINK_INSTALL_RUNNING_CHE_LOCALLY, MIN_CHE_OPERATOR_INSTALLER_VERSION, MIN_OLM_INSTALLER_VERSION } from '../../constants'
 import { CheTasks } from '../../tasks/che'
 import { DevWorkspaceTasks } from '../../tasks/component-installers/devfile-workspace-operator-installer'
 import { DexTasks } from '../../tasks/component-installers/dex'
@@ -26,7 +26,7 @@ import { checkChectlAndCheVersionCompatibility, createNamespaceTask, downloadTem
 import { InstallerTasks } from '../../tasks/installers/installer'
 import { ApiTasks } from '../../tasks/platforms/api'
 import { PlatformTasks } from '../../tasks/platforms/platform'
-import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, getTlsSupport, isDevWorkspaceEnabled, isKubernetesPlatformFamily, isNativeUserModeEnabled, isOpenshiftPlatformFamily, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
+import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, getTlsSupport, isDevWorkspaceEnabled, isKubernetesPlatformFamily, isOpenshiftPlatformFamily, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
 
 export default class Deploy extends Command {
   static description = 'Deploy CodeReady Workspaces server'
@@ -126,6 +126,10 @@ export default class Deploy extends Command {
       description: 'Skip cluster availability check. The check is a simple request to ensure the cluster is reachable.',
       default: false,
     }),
+    'skip-oidc-provider-check': flags.boolean({
+      description: 'Skip OIDC Provider check',
+      default: false,
+    }),
     'auto-update': flags.boolean({
       description: `Auto update approval strategy for installation CodeReady Workspaces.
                     With this strategy will be provided auto-update CodeReady Workspaces without any human interaction.
@@ -242,8 +246,8 @@ export default class Deploy extends Command {
         this.error(`🛑 The specified installer ${flags.installer} does not support Minishift`)
       }
 
-      if (flags[OLM.CHANNEL] === OLM_STABLE_ALL_NAMESPACES_CHANNEL_NAME && isKubernetesPlatformFamily(flags.platform)) {
-        this.error('"stable-all-namespaces" channel is supported only in "openshift" platform')
+      if (isKubernetesPlatformFamily(flags.platform)) {
+        this.error(`🛑 The specified installer ${flags.installer} does not support Kubernentes`)
       }
 
       if (flags[OLM.CATALOG_SOURCE_NAME] && flags[OLM.CATALOG_SOURCE_YAML]) {
@@ -330,12 +334,6 @@ export default class Deploy extends Command {
     await this.setPlaformDefaults(flags, ctx)
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Deploy.id, flags })
 
-    if (!flags.batch && isKubernetesPlatformFamily(flags.platform) && (isDevWorkspaceEnabled(ctx) || flags['workspace-engine'] === 'dev-workspace') && !isNativeUserModeEnabled(ctx)) {
-      if (!await cli.confirm('DevWorkspace is experimental feature. It requires direct access to the underlying infrastructure REST API.\nThis results in huge privilege escalation. Do you want to proceed? [y/n]')) {
-        cli.exit(0)
-      }
-    }
-
     const dexTasks = new DexTasks(flags)
     const cheTasks = new CheTasks(flags)
     const platformTasks = new PlatformTasks(flags)
@@ -353,17 +351,18 @@ export default class Deploy extends Command {
       title: '👀  Looking for an already existing CodeReady Workspaces instance',
       task: () => new Listr(cheTasks.checkIfCheIsInstalledTasks(flags)),
     })
+    preInstallTasks.add(ensureOIDCProviderInstalled(flags))
     preInstallTasks.add(checkChectlAndCheVersionCompatibility(flags))
     preInstallTasks.add(downloadTemplates(flags))
     preInstallTasks.add({
-      title: '🧪  DevWorkspace engine (experimental / technology preview) 🚨',
-      enabled: () => (isDevWorkspaceEnabled(ctx) || flags['workspace-engine'] === 'dev-workspace') && !ctx.isOpenShift,
+      title: '🧪  DevWorkspace engine',
+      enabled: () => isDevWorkspaceEnabled(ctx, flags) && !ctx.isOpenShift,
       task: () => new Listr(devWorkspaceTasks.getInstallTasks()),
     })
 
     const installTasks = new Listr(undefined, ctx.listrOptions)
     installTasks.add([createNamespaceTask(flags.chenamespace, this.getNamespaceLabels(flags))])
-    if (isKubernetesPlatformFamily(flags.platform) && isNativeUserModeEnabled(ctx)) {
+    if (flags.platform === 'minikube' && isDevWorkspaceEnabled(ctx, flags)) {
       installTasks.add(dexTasks.getInstallTasks())
     }
     installTasks.add(await installerTasks.installTasks(flags, this))
@@ -420,6 +419,37 @@ export default class Deploy extends Command {
   }
 }
 
+function ensureOIDCProviderInstalled(flags: any): Listr.ListrTask {
+  return {
+    title: 'Check if OIDC Provider installed',
+    enabled: ctx => !flags['skip-oidc-provider-check'] && isKubernetesPlatformFamily(flags.platform) && !ctx.isCheDeployed && isDevWorkspaceEnabled(ctx, flags),
+    skip: ctx => {
+      if (flags.platform === 'minikube' && isDevWorkspaceEnabled(ctx, flags)) {
+        return 'Dex will be automatically installed'
+      }
+    },
+    task: async (_ctx: any, task: any) => {
+      const kube = new KubeHelper(flags)
+      const apiServerPods = await kube.getPodListByLabel('kube-system', 'component=kube-apiserver')
+      for (const pod of apiServerPods) {
+        if (!pod.spec) {
+          continue
+        }
+        for (const container of pod.spec.containers) {
+          if (container.command) {
+            if (container.command.some(value => value.includes(OIDCContextKeys.ISSUER_URL) && value.includes(OIDCContextKeys.CLIENT_ID))) {
+              task.title = `${task.title}...OK`
+              return
+            }
+          }
+        }
+      }
+      task.title = `${task.title}...NOT INSTALLED`
+      throw new Error('OIDC Provider is not installed in order to deploy CodeReady Workspaces. To bypass OIDC Provider check use \'--skip-oidc-provider-check\' flag')
+    },
+  }
+}
+
 /**
  * Sets default installer which is `olm` for OpenShift 4 with stable version of crwctl
  * and `operator` for other cases.
