@@ -23,7 +23,7 @@ import { cheNamespace } from '../../common-flags'
 import { getBackupServerConfigurationName, parseBackupServerConfig, requestRestore } from '../../api/backup-restore'
 import { cli } from 'cli-ux'
 import { ApiTasks } from '../../tasks/platforms/api'
-import { TASK_TITLE_CREATE_CUSTOM_CATALOG_SOURCE_FROM_FILE, TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE, TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE, OLMTasks, TASK_TITLE_SET_CUSTOM_OPERATOR_IMAGE, TASK_TITLE_PREPARE_CHE_CLUSTER_CR } from '../../tasks/installers/olm'
+import { TASK_TITLE_CREATE_CUSTOM_CATALOG_SOURCE_FROM_FILE, TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE, TASK_TITLE_DELETE_NEXT_CATALOG_SOURCE, OLMTasks, TASK_TITLE_SET_CUSTOM_OPERATOR_IMAGE, TASK_TITLE_PREPARE_CHE_CLUSTER_CR } from '../../tasks/installers/olm'
 import { OperatorTasks } from '../../tasks/installers/operator'
 import { checkChectlAndCheVersionCompatibility, downloadTemplates, TASK_TITLE_CREATE_CHE_CLUSTER_CRD, TASK_TITLE_PATCH_CHECLUSTER_CR } from '../../tasks/installers/common-tasks'
 import { confirmYN, findWorkingNamespace, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
@@ -365,11 +365,11 @@ export default class Restore extends Command {
           // All preparations and validations must be done before this task!
           // Delete old operator if any in case of OLM installer.
           // For Operator installer, the operator deployment will be downgraded if needed.
-          const olmTasks = new OLMTasks()
+          const olmTasks = new OLMTasks(flags)
           let olmDeleteTasks = olmTasks.deleteTasks(flags)
           const tasksToDelete = [
             TASK_TITLE_DELETE_CUSTOM_CATALOG_SOURCE,
-            TASK_TITLE_DELETE_NIGHTLY_CATALOG_SOURCE,
+            TASK_TITLE_DELETE_NEXT_CATALOG_SOURCE,
           ]
           olmDeleteTasks = olmDeleteTasks.filter(task => tasksToDelete.indexOf(task.title) === -1)
           return new Listr(olmDeleteTasks, ctx.listrOptions)
@@ -402,7 +402,7 @@ export default class Restore extends Command {
 
             return new Listr(operatorUpdateTasks, ctx.listrOptions)
           } else { // OLM
-            const olmTasks = new OLMTasks()
+            const olmTasks = new OLMTasks(flags)
             let olmInstallTasks = olmTasks.startTasks(flags, this)
             // Remove redundant for restoring tasks
             const tasksToDelete = [
